==> billogram-foundation-2.3.0.tgz: package/modules/components/button/RouteButton.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { Link } from 'react-router';
import invariant from 'invariant';

import ButtonContent from './ButtonContent';

import isNullOrEmpty from '../../isNullOrEmpty';


export default ({
    block,
    displayName
}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    const Content = ButtonContent({ block, displayName: `${displayName}Content` });

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            disabled: PropTypes.bool,
            icon: PropTypes.string,
            stretched: PropTypes.bool,
            to: PropTypes.oneOfType([PropTypes.object, PropTypes.string]),
            ui: PropTypes.oneOfType([
                PropTypes.string,
                PropTypes.arrayOf(PropTypes.string)
            ])
        },

        getDefaultProps() {
            return {
                children: null,
                disabled: false,
                icon: null,
                query: '',
                to: '',
                ui: ''
            };
        },

        onClick(evt) {
            if (this.props.disabled) {
                evt.preventDefault();
            }
        },

        render() {
            const { children, disabled, icon, stretched, to, ui } = this.props;
            return (
                <Link
                    className={ block({ disabled, stretched }, typeof ui === 'string' ? [ui] : ui) }
                    onClick={ this.onClick }
                    tabIndex="0"
                    to={ to }>
                    <Content
                        icon={ icon }>
                        { children }
                    </Content>
                </Link>
            );
        }

    });

};

==> billogram-foundation-2.3.5.tgz: package/modules/components/button/RouteButton.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { Link } from 'react-router';
import invariant from 'invariant';

import ButtonContent from './ButtonContent';

import isNullOrEmpty from '../../isNullOrEmpty';


export default ({
    block,
    displayName
}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    const Content = ButtonContent({ block, displayName: `${displayName}Content` });

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            disabled: PropTypes.bool,
            icon: PropTypes.string,
            to: PropTypes.oneOfType([PropTypes.object, PropTypes.string]),
            ui: PropTypes.oneOfType([
                PropTypes.string,
                PropTypes.arrayOf(PropTypes.string)
            ])
        },

        getDefaultProps() {
            return {
                children: null,
                disabled: false,
                icon: null,
                query: '',
                to: '',
                ui: ''
            };
        },

        onClick(evt) {
            if (this.props.disabled) {
                evt.preventDefault();
            }
        },

        render() {
            const { children, disabled, icon, to, ui } = this.props;
            return (
                <Link
                    className={ block({ disabled }, typeof ui === 'string' ? [ui] : ui) }
                    onClick={ this.onClick }
                    tabIndex="0"
                    to={ to }>
                    <Content
                        icon={ icon }>
                        { children }
                    </Content>
                </Link>
            );
        }

    });

};
